@@ -4,6 +4,7 @@ __author__  = 'Taito Horiuchi <taito.horiuchi@abita.fi>'
 __docformat__ = 'plaintext'
 
 import md5
+import re
 from email import Encoders
 from email.MIMEMultipart import MIMEMultipart
 from email.MIMEText import MIMEText
@@ -15,40 +16,29 @@ from Acquisition import aq_chain, aq_inner,aq_parent
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.utils import safe_unicode
 from Products.Archetypes.public import (
-#    ATFieldProperty,
     DisplayList,
     Schema,
-#    registerType,
 )
 from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.folder import ATFolderSchema, ATFolder
-from Products.ATContentTypes.configuration import zconf
-#from Products.Archetypes.public import RFC822Marshaller
-from Products.statusmessages.interfaces import IStatusMessage
 
 from Products.ATContentTypes.content.document import finalizeATCTSchema
 
 from Products.PloneFormGen.content.actionAdapter import (
     AnnotationStorage,
-#    FormActionAdapter,
-#    FormAdapterSchema,
     BooleanField,
     IntegerField,
     LinesField,
     StringField,
-    TextField,
     BooleanWidget,
     IntegerWidget,
     LinesWidget,
     MultiSelectionWidget,
-    RichWidget,
     SelectionWidget,
     StringWidget,
-#    TextAreaWidget,
 )
 from Products.PloneFormGen.content.formMailerAdapter import formMailerAdapterSchema, FormMailerAdapter
 from Products.PloneFormGen import HAS_PLONE25, HAS_PLONE30
-#from Products.PloneFormGen.interfaces import IPloneFormGenField
 from Products.PloneFormGen.content.fieldsBase import BaseFormField
 from Products.PloneFormGen.content.thanksPage import FormThanksPage, ThanksPageSchema
 
@@ -64,6 +54,10 @@ def check_float(value):
     except TypeError:
         return False
 
+def remove_html_tags(data):
+    p = re.compile(r'<.*?>')
+    return p.sub('', data)
+
 PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() + ThanksPageSchema.copy() + Schema((
 
     BooleanField(
@@ -216,36 +210,20 @@ PFGVerkkomaksutSchema.moveField('thanksPrologue', before='cancel_message')
 del PFGVerkkomaksutSchema['thanksEpilogue']
 del PFGVerkkomaksutSchema['noSubmitMessage']
 
-#finalizeATCTSchema(PFGVerkkomaksutSchema)
 finalizeATCTSchema(PFGVerkkomaksutSchema, folderish=True, moveDiscussion=False)
 
-#class PFGVerkkomaksut(FormActionAdapter, FormMailerAdapter):
-#class PFGVerkkomaksut(FormMailerAdapter):
 class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
-#class PFGVerkkomaksut(FormMailerAdapter, ATFolder):
     """Verkkomaksut Payment Adapter"""
 
     # Standard content type setup
     portal_type = meta_type = 'PFGVerkkomaksut'
     archetype_name = 'Verkkomaksut Payment Adapter'
     schema = PFGVerkkomaksutSchema
-#    typeDescription = 'A document which can contain rich text, images and attachments'
-#    typeDescMsgId = 'PFGVerkkomaksut_description_edit'
     content_icon = 'mailaction.gif'
     default_view = immediate_view = 'base_view'
-
     _at_rename_after_creation = True
-
     __implements__ = (ATFolder.__implements__, )
 
-
-#    merchant_id = ATFieldProperty('merchant_id')
-#    merchant_authentication_code = ATFieldProperty('merchant_authentication_code')
-#    next_order_number = ATFieldProperty('next_order_number')
-#    price_field = ATFieldProperty('price_field')
-#    thanks_text = ATFieldProperty('thanks_text')
-#    cancel_message = ATFieldProperty('cancel_message')
-
     def canSetDefaultPage(self):
         return False
 
@@ -262,10 +240,6 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         price = form.get(field)
         MERCHANT_ID = str(self.getMerchant_id())
         AMOUNT = price
-#        order_number = self.getNext_order_number()
-#        ORDER_NUMBER = str(order_number)
-#        # Increase next_order_number by one.
-#        self.setNext_order_number(order_number + 1)
         ORDER_DESCRIPTION = self.order_description(fields, REQUEST)
         CURRENCY = 'EUR'
 #        portal = getToolByName(self, 'portal_url').getPortalObject()
@@ -330,16 +304,6 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         )
 
         session.set('pfg.verkkomaksut', value)
-#        res = [
-#            dict(
-#                title=field.Title(),
-#                description=form.get(field.getId()),
-#            ) for field in fields
-#        ]
-##        for field in fields:
-##            id = field.getId()
-##            res.update({id:form.get(id)})
-#        session.set('pfg.verkkomaksut.fields', res)
         session.set('pfg.verkkomaksut.fields', self.displayInputs(REQUEST))
 
 
@@ -347,9 +311,10 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         return self.REQUEST.RESPONSE.redirect(url)
 
     def order_description(self, fields, REQUEST=None):
-#        self.displayInputs(REQUEST)
-        parent = aq_parent(self)
-        labels = [parent[id].Title() for id in self.getOrder_description()]
+        folder = aq_parent(self)
+        obj_ids = [obj.id for obj in folder.contentValues() if isinstance(obj, BaseFormField)]
+        ids = [id for id in self.getOrder_description() if id in obj_ids]
+        labels = [folder[id].Title() for id in ids]
         items = {}
         for item in self.displayInputs(REQUEST):
             items.update({item.get('label'):item.get('value')})
@@ -358,6 +323,8 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         else:
             values = [safe_unicode(items.get(label)) for label in labels if items.get(label) is not None and items.get(label) != '']
             res = u','.join(values)
+            res = remove_html_tags(res)
+            res = res.replace('\r', ',')
             portal = getToolByName(self, 'portal_url').getPortalObject()
             charset = portal.getProperty('email_charset', 'utf-8')
             return res[:65000].encode(charset)
@@ -433,7 +400,6 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         host = self.MailHost
         host.send(mailtext)
 
-
     def attachments(self):
         dl = DisplayList()
         catalog = getToolByName(self, 'portal_catalog')
@@ -467,7 +433,6 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
             items = [item[:item.find('|')] for item in field.getObject().getFgVocabulary()]
             filtered_items = [item for item in items if check_float(item)]
             if items != filtered_items or len(items) == len(filtered_items) == 0:
-#                selection_fields.remove(field)
                 selection_fields = [sf for sf in selection_fields if sf.id != field.id]
         selection_fields = [(brain.getObject().UID(), brain.Title) for brain in selection_fields]
         fields = fixed_point_fields + selection_fields
